@@ -20,7 +20,7 @@ class AdsApi:
     base_url_ads: str
     lock: Lock = mp.Lock()
 
-    def request(self, endpoint: str, params: dict | None = None, data: dict | None = None, attempts: int = 5, method:str = 'GET'):
+    def request(self, endpoint: str, params: dict | None = None, data: dict | None = None, attempts: int = 5, method:str = 'GET', json:dict = None):
         req_info = f'request {self.base_url_ads+endpoint}\n data = {data}\n params = {params}\n'
         for attempt in range(attempts):
             try:
@@ -32,7 +32,7 @@ class AdsApi:
                         if data[i] == None:
                             del data[i]
                 response = methods[method](
-                    self.base_url_ads + endpoint, params=params, data=data).json()
+                    self.base_url_ads + endpoint, params=params, data=data, json=json).json()
                 self.lock.release()
             except:
                 log.error(f'Error with {req_info}-- {traceback.format_exc()}')
@@ -81,7 +81,7 @@ class AdsApi:
                        country: str | None = None, city: str | None = None, remark: str | None = None,
                        user_proxy_config: dict = UserProxyConfig().dict(), fingerprint_config: dict =FingepringConfig().dict()) -> dict:
         resp = self.request('/api/v1/user/create',
-                            data={'name': name, 'domain_name': domain_name, 'open_urls':open_urls, 'repeat_config':repeat_config, 'username':username,
+                            json={'name': name, 'domain_name': domain_name, 'open_urls':open_urls, 'repeat_config':repeat_config, 'username':username,
                                     'password':password, 'cookie':cookie, 'ignore_cookie_error':ignore_cookie_error, 'group_id':group_id,
                                     'ip':ip, 'country':country, 'city':city, 'remark':remark, 'user_proxy_config':user_proxy_config,
                                     'fingerprint_config':fingerprint_config}, method='POST')
