@@ -2,7 +2,7 @@ from pydantic import BaseModel
 
 
 class UserProxyConfig(BaseModel):
-    proxy_soft: str
+    proxy_soft: str | None = None
     proxy_type: str | None = None
     proxy_host: str | None = None
     proxy_port: str | None = None
